@@ -10,7 +10,10 @@ mod tests {
 
     #[cfg(feature = "separate-chaining-test")]
     mod separate_chaining_test {
-        use crate::{Map, MapMut, MapUtil, SCHashMap};
+        use crate::{
+            map::{IntoMapUtil, Map, MapMut, MapSize},
+            util::SCHashMap,
+        };
 
         #[test]
         fn get_test_0() {
@@ -76,21 +79,68 @@ mod tests {
         }
 
         #[test]
-        #[ignore = "not yet implemented"]
-        fn entries() {
-            todo!()
+        fn iter() {
+            let mut data = vec![
+                ("4", "four"),
+                ("69", "sixty-nine"),
+                ("2", "two"),
+                ("69", "four-twenty"),
+            ];
+
+            let map: SCHashMap<&str, &str> = data.clone().into();
+            let mut result: Vec<(&str, &str)> = map.into_iter().collect();
+
+            //  Remove the replaced value
+            data.remove(1);
+
+            data.sort();
+            result.sort();
+
+            assert_eq!(data, result)
         }
 
         #[test]
-        #[ignore = "not yet implemented"]
         fn keys() {
-            todo!()
+            let mut data = vec![
+                ("4", "four"),
+                ("69", "sixty-nine"),
+                ("2", "two"),
+                ("69", "four-twenty"),
+            ];
+
+            let map: SCHashMap<&str, &str> = data.clone().into();
+            let mut result: Vec<&str> = map.into_keys().collect();
+
+            //  Remove the replaced value
+            data.remove(1);
+            let mut data: Vec<&str> = data.into_iter().map(|(k, _)| k).collect();
+
+            data.sort();
+            result.sort();
+
+            assert_eq!(data, result)
         }
 
         #[test]
-        #[ignore = "not yet implemented"]
         fn values() {
-            todo!()
+            let mut data = vec![
+                ("4", "four"),
+                ("69", "sixty-nine"),
+                ("2", "two"),
+                ("69", "four-twenty"),
+            ];
+
+            let map: SCHashMap<&str, &str> = data.clone().into();
+            let mut result: Vec<&str> = map.into_values().collect();
+
+            //  Remove the replaced value
+            data.remove(1);
+            let mut data: Vec<&str> = data.into_iter().map(|(_, v)| v).collect();
+
+            data.sort();
+            result.sort();
+
+            assert_eq!(data, result)
         }
     }
 
@@ -98,7 +148,10 @@ mod tests {
     mod open_addressing_tests {
         #[cfg(feature = "linear-probing-test")]
         mod linear_probing_test {
-            use crate::{LPHashMap, Map, MapMut, MapUtil};
+            use crate::{
+                map::{IntoMapUtil, Map, MapMut, MapSize},
+                util::LPHashMap,
+            };
 
             #[test]
             fn get_test_0() {
@@ -164,27 +217,77 @@ mod tests {
             }
 
             #[test]
-            #[ignore = "not yet implemented"]
-            fn entries() {
-                todo!()
+            fn iter() {
+                let mut data = vec![
+                    ("4", "four"),
+                    ("69", "sixty-nine"),
+                    ("2", "two"),
+                    ("69", "four-twenty"),
+                ];
+
+                let map: LPHashMap<&str, &str> = data.clone().into();
+                let mut result: Vec<(&str, &str)> = map.into_iter().collect();
+
+                //  Remove the replaced value
+                data.remove(1);
+
+                data.sort();
+                result.sort();
+
+                assert_eq!(data, result)
             }
 
             #[test]
-            #[ignore = "not yet implemented"]
             fn keys() {
-                todo!()
+                let mut data = vec![
+                    ("4", "four"),
+                    ("69", "sixty-nine"),
+                    ("2", "two"),
+                    ("69", "four-twenty"),
+                ];
+
+                let map: LPHashMap<&str, &str> = data.clone().into();
+                let mut result: Vec<&str> = map.into_keys().collect();
+
+                //  Remove the replaced value
+                data.remove(1);
+                let mut data: Vec<&str> = data.into_iter().map(|(k, _)| k).collect();
+
+                data.sort();
+                result.sort();
+
+                assert_eq!(data, result)
             }
 
             #[test]
-            #[ignore = "not yet implemented"]
             fn values() {
-                todo!()
+                let mut data = vec![
+                    ("4", "four"),
+                    ("69", "sixty-nine"),
+                    ("2", "two"),
+                    ("69", "four-twenty"),
+                ];
+
+                let map: LPHashMap<&str, &str> = data.clone().into();
+                let mut result: Vec<&str> = map.into_values().collect();
+
+                //  Remove the replaced value
+                data.remove(1);
+                let mut data: Vec<&str> = data.into_iter().map(|(_, v)| v).collect();
+
+                data.sort();
+                result.sort();
+
+                assert_eq!(data, result)
             }
         }
 
         #[cfg(feature = "double-hashing-test")]
         mod double_hashing_test {
-            use crate::{DHHashMap, Map, MapMut, MapUtil};
+            use crate::{
+                map::{IntoMapUtil, Map, MapMut, MapSize},
+                util::DHHashMap,
+            };
 
             #[test]
             fn get_test_0() {
@@ -250,27 +353,77 @@ mod tests {
             }
 
             #[test]
-            #[ignore = "not yet implemented"]
-            fn entries() {
-                todo!()
+            fn iter() {
+                let mut data = vec![
+                    ("4", "four"),
+                    ("69", "sixty-nine"),
+                    ("2", "two"),
+                    ("69", "four-twenty"),
+                ];
+
+                let map: DHHashMap<&str, &str> = data.clone().into();
+                let mut result: Vec<(&str, &str)> = map.into_iter().collect();
+
+                //  Remove the replaced value
+                data.remove(1);
+
+                data.sort();
+                result.sort();
+
+                assert_eq!(data, result)
             }
 
             #[test]
-            #[ignore = "not yet implemented"]
             fn keys() {
-                todo!()
+                let mut data = vec![
+                    ("4", "four"),
+                    ("69", "sixty-nine"),
+                    ("2", "two"),
+                    ("69", "four-twenty"),
+                ];
+
+                let map: DHHashMap<&str, &str> = data.clone().into();
+                let mut result: Vec<&str> = map.into_keys().collect();
+
+                //  Remove the replaced value
+                data.remove(1);
+                let mut data: Vec<&str> = data.into_iter().map(|(k, _)| k).collect();
+
+                data.sort();
+                result.sort();
+
+                assert_eq!(data, result)
             }
 
             #[test]
-            #[ignore = "not yet implemented"]
             fn values() {
-                todo!()
+                let mut data = vec![
+                    ("4", "four"),
+                    ("69", "sixty-nine"),
+                    ("2", "two"),
+                    ("69", "four-twenty"),
+                ];
+
+                let map: DHHashMap<&str, &str> = data.clone().into();
+                let mut result: Vec<&str> = map.into_values().collect();
+
+                //  Remove the replaced value
+                data.remove(1);
+                let mut data: Vec<&str> = data.into_iter().map(|(_, v)| v).collect();
+
+                data.sort();
+                result.sort();
+
+                assert_eq!(data, result)
             }
         }
 
         #[cfg(feature = "quadratic-probing-test")]
         mod quadratic_probing_test {
-            use crate::{Map, MapMut, MapUtil, QPHashMap};
+            use crate::{
+                map::{IntoMapUtil, Map, MapMut, MapSize},
+                util::QPHashMap,
+            };
 
             #[test]
             fn get_test_0() {
@@ -336,21 +489,68 @@ mod tests {
             }
 
             #[test]
-            #[ignore = "not yet implemented"]
-            fn entries() {
-                todo!()
+            fn iter() {
+                let mut data = vec![
+                    ("4", "four"),
+                    ("69", "sixty-nine"),
+                    ("2", "two"),
+                    ("69", "four-twenty"),
+                ];
+
+                let map: QPHashMap<&str, &str> = data.clone().into();
+                let mut result: Vec<(&str, &str)> = map.into_iter().collect();
+
+                //  Remove the replaced value
+                data.remove(1);
+
+                data.sort();
+                result.sort();
+
+                assert_eq!(data, result)
             }
 
             #[test]
-            #[ignore = "not yet implemented"]
             fn keys() {
-                todo!()
+                let mut data = vec![
+                    ("4", "four"),
+                    ("69", "sixty-nine"),
+                    ("2", "two"),
+                    ("69", "four-twenty"),
+                ];
+
+                let map: QPHashMap<&str, &str> = data.clone().into();
+                let mut result: Vec<&str> = map.into_keys().collect();
+
+                //  Remove the replaced value
+                data.remove(1);
+                let mut data: Vec<&str> = data.into_iter().map(|(k, _)| k).collect();
+
+                data.sort();
+                result.sort();
+
+                assert_eq!(data, result)
             }
 
             #[test]
-            #[ignore = "not yet implemented"]
             fn values() {
-                todo!()
+                let mut data = vec![
+                    ("4", "four"),
+                    ("69", "sixty-nine"),
+                    ("2", "two"),
+                    ("69", "four-twenty"),
+                ];
+
+                let map: QPHashMap<&str, &str> = data.clone().into();
+                let mut result: Vec<&str> = map.into_values().collect();
+
+                //  Remove the replaced value
+                data.remove(1);
+                let mut data: Vec<&str> = data.into_iter().map(|(_, v)| v).collect();
+
+                data.sort();
+                result.sort();
+
+                assert_eq!(data, result)
             }
         }
     }
